@@ -59,8 +59,7 @@ class InstallService:
         print(" - Create a user named 'rpi-intercom' with limited permissions to run the intercom service")
         print(" - Install the rpi-intercom service")
         print(" - Configure the service to start at boot")
-
-        if "--agree" not in sys.argv:
+        if "accept" not in sys.argv[2]:
             print("Do you want to continue [yes/no]?")
             response = input()
             if not response.lower().startswith("y"):
