@@ -4,13 +4,14 @@ from threading import Event, Thread
 from datetime import datetime, timedelta
 from time import sleep
 import os
+import psutil
 
 class Shutdown():
     def __init__(self, config: Config):
         self._config = config
         self._shutdown_indicator = Event()
         self._shutdown_requested = None
-        self._shutdown_thread = Thread(name="Shutdown watcher", daemon=True)
+        self._shutdown_thread = Thread(name="Shutdown watcher", daemon=True, target=self.watch_for_shutdown)
 
     @property
     def shutting_down(self):
@@ -33,5 +34,5 @@ class Shutdown():
         # Wait 3 seconds for a clean exit, then exit garcelessly.
         sleep(3)
         print("Things couldn't get cleaned up, exiting gracelessly")
-        os._exit()
+        psutil.Process(os.getpid()).kill()
 
